/*
cmd: +w640 +h360 +a0.05 +am3 +ac0.90 +r3 -kc +kfi0 +kff450

*/
#version 3.7;
#include "math.inc"
#include "waveheader.inc"
#include "povosc.inc"

global_settings{ assumed_gamma 1.0 }
#default{ finish{ ambient 0.1 diffuse 0.9 }} 
#declare TAU = 2*pi;
#declare Clock = 0.43;

#if(Clock<=0.5)
  #declare MVPhase = adj_range2(Clock,0.0,0.5,0.5*pi,0.0);
  #declare DT1     = adj_range2(Clock,0.0,0.5,0.03   ,0.4);
  #declare DT2     = adj_range2(Clock,0.0,0.5,0.5    ,0.75);
  #declare DT3     = adj_range2(Clock*3,0.0,0.5,0.75   ,0.5);  
#else
  #declare MVPhase = adj_range2(Clock,0.5,1.0,0.0,0.5*pi);
  #declare DT1     = adj_range2(Clock,0.5,1.0,0.4,0.03);
  #declare DT2     = adj_range2(Clock/2,0.0,1.0,0.75   ,0.5);
  #declare DT3     = adj_range2(Clock,0.0,1.0,0.5    ,0.75);
#end 

#if(Clock>0.8)
  #declare DT4     = adj_range2(Clock,0.8,1.0,0.8,0.8);
#else
  #declare DT4     = adj_range2(Clock,0.8,1.0,1,1);
#end

#declare T_arr = array[5]{0,DT1,DT2,DT3,DT4}
#declare Spl_x = array[5]{0,0.25,0.5,0.75,1}
#declare PDSpl = function{
  spline {
    linear_spline
    T_arr[0], <Spl_x[0], 0.00> 
    T_arr[1], <Spl_x[1], 0.25> 
    T_arr[2], <Spl_x[2], 0.50>
    T_arr[3], <Spl_x[3], 0.75> 
    T_arr[4], <Spl_x[4], 1.00>
  }
}


#for(i, 0, 1, 0.015)
  sphere{<i*TAU, -1.5, 0.5>, 0.041 pigment{#if(i=0.3) rgb<1,0,0> #else rgb 0 #end}}
  sphere{<TAU*PDSpl(i).x, 0, 0.5>, 0.041 pigment{#if(i=0.3) rgb<1,0,0> #else rgb 0 #end}} 
  cylinder{<i*TAU, -1.5, 0.5>, <TAU*PDSpl(i).x, 0, 0.5>, 0.005 pigment{#if(i=0.3) rgb<1,0,0> #else rgb 0 #end}}
#end

camera {
  perspective 
  angle 50 
  location  <pi , 2.5 ,-6.0>
  look_at   <pi , -0.5 , 0.0>
  right     x*image_width/image_height
  aperture 3
  blur_samples 90
  focal_point <0,1.1,0>
}

light_source{< pi,0,-3000> color rgb 1 shadowless}
